@@ -67,12 +67,12 @@ Tork_plug_in::Tork_plug_in( TQObject* parent, const char* name )
     TDEActionMenu *menu = new TDEActionMenu( i18n("Anonymity Manager"), pix,
                                          actionCollection(), "tork_menu" );
     menu->setDelayed( false );
-    connect( menu->popupMenu(), SIGNAL( aboutToShow() ), SLOT( showPopup() ));
+    connect( menu->popupMenu(), TQ_SIGNAL( aboutToShow() ), TQ_SLOT( showPopup() ));
 
     m_paToggleTDE=new TDEAction(i18n("Anonymize TDE"),
                                            TDEGlobal::iconLoader()->loadIconSet("tork_konqueroroff",                                               TDEIcon::Small),
                                            TDEShortcut(),
-                                           this, SLOT(toggleTDE()),
+                                           this, TQ_SLOT(toggleTDE()),
                                            actionCollection(), "tork_konqueroron" );
 
     menu->insert( m_paToggleTDE );
@@ -81,14 +81,14 @@ Tork_plug_in::Tork_plug_in( TQObject* parent, const char* name )
     TDEAction *m_firefox=new TDEAction(i18n("Re-Open Anonymously with Firefox"),
                                            TDEGlobal::iconLoader()->loadIconSet("tork_firefox",                                               TDEIcon::Small),
                                            TDEShortcut(),
-                                           this, SLOT(openWithFirefox()),
+                                           this, TQ_SLOT(openWithFirefox()),
                                            actionCollection(), "tork_firefox" );
     menu->insert( m_firefox );
 
     TDEAction *m_opera=new TDEAction(i18n("Re-Open Anonymously with Opera"),
                                            TDEGlobal::iconLoader()->loadIconSet("tork_opera",                                               TDEIcon::Small),
                                            TDEShortcut(),
-                                           this, SLOT(openWithOpera()),
+                                           this, TQ_SLOT(openWithOpera()),
                                            actionCollection(), "tork_opera" );
     menu->insert( m_opera );
 
