@@ -64,14 +64,14 @@ TorClient::TorClient( const TQString &host, TQ_UINT16 port )
 {
     // create the socket and connect various of its signals
     socket = new TQSocket( this );
-    connect( socket, SIGNAL(connected()),
-            SLOT(socketConnected()) );
-    connect( socket, SIGNAL(connectionClosed()),
-            SLOT(socketConnectionClosed()) );
-    connect( socket, SIGNAL(readyRead()),
-            SLOT(socketReadyRead()) );
-    connect( socket, SIGNAL(error(int)),
-            SLOT(socketError(int)) );
+    connect( socket, TQ_SIGNAL(connected()),
+            TQ_SLOT(socketConnected()) );
+    connect( socket, TQ_SIGNAL(connectionClosed()),
+            TQ_SLOT(socketConnectionClosed()) );
+    connect( socket, TQ_SIGNAL(readyRead()),
+            TQ_SLOT(socketReadyRead()) );
+    connect( socket, TQ_SIGNAL(error(int)),
+            TQ_SLOT(socketError(int)) );
 
     // connect to the server
     //infoText->append( tr("Trying to connect to the server\n") );
